.. _ext:

**********
Extensions
**********

Here you can find a list of packages that extend Mopidy with additional
functionality. This list is moderated and updated on a regular basis. If you
want your package to show up here, follow the :ref:`guide on creating
extensions <extensiondev>`.


Bundled with Mopidy
===================

These extensions are maintained by Mopidy's core developers. They are installed
together with Mopidy and are enabled by default.

.. toctree::
    :maxdepth: 1
    :glob:

    **


External extensions
===================

These extensions are maintained outside Mopidy's core, often by other
developers.


Mopidy-Beets
------------

Provides a backend for playing music from your `Beets
<http://beets.radbox.org/>`_ music library through Beets' web extension.

Author:
    Janez Troha
PyPI:
    `Mopidy-Beets <https://pypi.python.org/pypi/Mopidy-Beets>`_
GitHub:
    `dz0ny/mopidy-beets <https://github.com/dz0ny/mopidy-beets>`_
Issues:
    https://github.com/dz0ny/mopidy-beets/issues


Mopidy-NAD
----------

Extension for controlling volume using an external NAD amplifier.

Author:
    Stein Magnus Jodal
PyPI:
    `Mopidy-NAD <https://pypi.python.org/pypi/Mopidy-NAD>`_
GitHub:
    `mopidy/mopidy-nad <https://github.com/mopidy/mopidy-nad>`_
Issues:
    https://github.com/mopidy/mopidy/issues


Mopidy-SoundCloud
-----------------

Provides a backend for playing music from the `SoundCloud
<http://www.soundcloud.com/>`_ service.

Author:
    Janez Troha
PyPI:
    `Mopidy-SoundCloud <https://pypi.python.org/pypi/Mopidy-SoundCloud>`_
GitHub:
    `dz0ny/mopidy-soundcloud <https://github.com/dz0ny/mopidy-soundcloud>`_
Issues:
    https://github.com/dz0ny/mopidy-soundcloud/issues
